OC.L10N.register(
    "deck",
    {
    "Personal" : "Shaxsiy",
    "Done" : "Bajarildi",
    "Cancel" : "Bekor qilish",
    "Tags" : "Teglar",
    "Can edit" : "Tahrirlashi mumkin",
    "Delete" : "O'chir",
    "Comments" : "Fikrlar",
    "Save" : "Saqlash",
    "Update" : "Yangilash",
    "seconds ago" : "soniya oldin",
    "Shared with you" : "Siz bilan baham ko'rdim"
},
"nplurals=1; plural=0;");
